# Mosip Authentication SDK

# Usage


# Prerequisites for building
* Python 3 (tested on 3.10.7), lower versions may or may not work.
* Poetry (recommended, optional)
  install
  ```sh
  python3 -m pip install poetry
  ```
  
# Dependencies for building
  ```sh
    python3 -m poetry install
  ```
  If you don't want to use poetry you can install the requirements directly using pip
  ```sh
  python3 -m pip install -r requirements.txt
  ```
# Build
    ```sh
    python3 -m poetry build
    ```

# Publish
```sh
    python3 -m poetry publish
```

# Testing
